@@ -1,5 +1,5 @@
 """
- * $Id: 1.0+7 utils.py 37697a1cc48d 2020-07-08 od $
+ * $Id: 1.0+8 utils.py a92a642340f2 2021-02-12 francesco.serafin.3@gmail.com $
  *
  * This file is part of the Cloud Services Integration Platform (CSIP),
  * a Model-as-a-Service framework, API and application suite.
@@ -40,6 +40,8 @@ class Client(object):
     KEY_UNIT = "unit"
     KEY_DESCRIPTION = "description"
     KEY_PATH = "path"
+    KEY_TYPE = "type"
+    KEY_COORD = "coordinates"
 
     META_KEY_SUID = "suid"
     META_KEY_STATUS = "status"
@@ -474,7 +476,7 @@ class Client(object):
             The entry must exist"""
         self.data[name][self.KEY_VALUE] = value
 
-    def add_data(self, name, value=None, descr: str = None, unit: str = None) -> None:
+    def add_data(self, name, value=None, descr: str = None, unit: str = None, geometry_type: str = None, coord: [] = None) -> None:
         """Add a new entry to the data"""
         if isinstance(name, Dict):
             # name is the the json data object 
@@ -491,6 +493,10 @@ class Client(object):
             self.data[name][self.KEY_UNIT] = unit
         if descr is not None:
             self.data[name][self.KEY_DESCRIPTION] = descr
+        if geometry_type is not None:
+            self.data[name][self.KEY_TYPE] = geometry_type
+        if coord is not None:
+            self.data[name][self.KEY_COORD] = coord
 
     def has_data(self, name: str) -> bool:
         """Check if data entry exists """
